/****************************************************************************
**              DISCLAIMER  
**  
**      Novell, Inc. makes no representations or warranties with respect to
**      any NetWare software, and specifically disclaims any express or
**      implied warranties of merchantability, title, or fitness for a
**      particular purpose.  
**
**      Distribution of any NetWare software is forbidden without the
**      express written consent of Novell, Inc.  Further, Novell reserves
**      the right to discontinue distribution of any NetWare software.
**      
**      Novell is not responsible for lost profits or revenue, loss of use
**      of the software, loss of data, costs of re-creating lost data, the
**      cost of any substitute equipment or program, or claims by any party
**      other than you.  Novell strongly recommends a backup be made before
**      any software is installed.   Technical support for this software
**      may be provided at the discretion of Novell.
****************************************************************************
**
**      File: ADDPSERV.C  
**
**      Desc:   To add or delete a USER in the PRINT SERVER LIST  
**              of the PRINTSERVER that you have defined in pconsole or with
**              the API calls.  This program is used in conjunction with
**              READQ.C.
**
**      Example: The following is a picture of the bindery and the TESTQUEUE
**               queue with its associated Objects,Propertys, and Values.
**
**          Object: TESTQUEUE (this is the queue name in bindery)
**                   -> ID: 04000006     Type: 3     Class: static 
**                  Security: 31     Has Properties: Yes
**          PROPERTY:
**            Q_DIRECTORY    
**            Class: static     Type: item     Sec: 33     Val: Yes
**            53 59 53 3a 2f 53 59 53 54 45 4d 2f 30 34 30 30 
**            30 30 30 36 2e 51 44 52 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**            00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 
**          PROPERTY:
**            Q_OPERATORS    
**            Class: static     Type: set      Sec: 31     Val: Yes
**            SUPERVISOR
**
**        PROPERTY:
**            Q_SERVERS (The QUEUE SERVERS are listed here)     
**            Class: static     Type: set      Sec: 31     Val: Yes
**            PSERVER              SUPERVISOR  (NOTE: supervisor added using
**                                            this program)
**
**        PROPERTY:
**            Q_USERS        
**            Class: static     Type: set      Sec: 31     Val: Yes
**            EVERYONE             
**
**
**      Parameter descriptions:    > input
**                                 < output
**
**           
**      Programmers:
**      Ini   Who                     Firm
**      ------------------------------------------------------------------
**      ARM   A. Ray Maxwell          Novell Developer Support.
**
**      History:
**       
**      ------------------------------------------------------------------
**      11-08-94      ARM     First code.
*/

/***************************************************************************
**      Include headers, macros, function prototypes, etc.
*/

   /*------------------------------------------------------------------
   **      ANSI
   */
   #include <stdlib.h>             /* exit(), atol()                 */
   #include <stdio.h>              /* sprintf()                      */
   #include <string.h>             /* strcpy()                       */
   #include <conio.h>
   #include <ctype.h>              /*toupper()                       */

   /*------------------------------------------------------------------
   **      NetWare
   */
   #include <nwcalls.h>

   /*------------------------------------------------------------------
   **      Defines
   */
   #define NWDOS
   #define MAXNAME 47
   #define MAXPATH 254
   #define TRUE    1
   #define FALSE   0

/****************************************************************************
**      Program Start
*/
void main(int argc, char *argv[])
{
   NWCCODE       ccode;

   /*------------------------------------------------------------------
   **      NWCreateQueue variables.
   */
   NWCONN_HANDLE  connID;
   char           queueName[MAXNAME+1];
   NWOBJ_TYPE     queueType;
   NWDIR_ID       dirPath;
   char           pathName[MAXPATH+1];
   NWOBJ_ID       queueID;
   char           userName[MAXPATH+1];
   char           serverName[MAXPATH+1];
   char           input;
   int            addflag;


   if(argc != 4) {
      printf("Usage: ADDPSERV <username> <servername> <queueName>\n");
      exit(1);
   }
   strcpy(userName, strupr(argv[1]));
   strcpy(serverName,  strupr(argv[2]));
   strcpy(queueName, strupr(argv[3]));
   clrscr();
   printf("(A)dd user to the Q_SERVERS property in the bindery.\n\n");
   printf("(D)elete user from the Q_SERVERS property in the bindery.\n");
   input=getch();

   if(toupper(input)=='A')
      addflag=TRUE;
   else 
      addflag=FALSE;


   ccode=NWCallsInit(NULL,NULL);
   if (ccode)
      exit(1);
   ccode=NWGetConnectionHandle(serverName,NULL,&connID,NULL);
   if (ccode){
      printf("NWGetConnectionHandle failed with error code %x\n",ccode);
      exit (ccode);
   }
    if(addflag){
      /*------------------------------------------------------------------
      **      Add the USER to the set of Q_SERVER in the bindery.
      */
      ccode=NWAddObjectToSet( connID,
                queueName,
                OT_PRINT_QUEUE,
                "Q_SERVERS",
                userName,
                OT_USER);
      if (ccode){
         printf("NWAddObjectToSet failed with error code %x\n",ccode);
         exit (ccode);
      }
   }
   else{
      /*------------------------------------------------------------------
      **      Delete USER from the set of Q_SERVER in the bindery.
      */
      ccode=NWDeleteObjectFromSet( connID,
                queueName,
                OT_PRINT_QUEUE,
                "Q_SERVERS",
                userName,
                OT_USER);
      if (ccode){
         printf("NWDeleteAddObjectFromSet failed with error code %x\n",ccode);
         exit (ccode);

      }
   }
}
